==> kubernetes-model-autoscaling-6.3.0-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2/ResourceMetricSourceFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface ResourceMetricSourceFluent<A extends ResourceMetricSourceFluent<A>> extends Fluent<A>{
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  
  /**
   * This method has been deprecated, please use method buildTarget instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricTarget getTarget();
  public MetricTarget buildTarget();
  public A withTarget(MetricTarget target);
  public Boolean hasTarget();
  public ResourceMetricSourceFluent.TargetNested<A> withNewTarget();
  public ResourceMetricSourceFluent.TargetNested<A> withNewTargetLike(MetricTarget item);
  public ResourceMetricSourceFluent.TargetNested<A> editTarget();
  public ResourceMetricSourceFluent.TargetNested<A> editOrNewTarget();
  public ResourceMetricSourceFluent.TargetNested<A> editOrNewTargetLike(MetricTarget item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface TargetNested<N> extends Nested<N>,MetricTargetFluent<ResourceMetricSourceFluent.TargetNested<N>>{
    public N and();
    public N endTarget();
    
  }
  
}

==> kubernetes-model-autoscaling-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2/ResourceMetricSourceFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ResourceMetricSourceFluent<A extends ResourceMetricSourceFluent<A>> extends Fluent<A>{
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  
  /**
   * This method has been deprecated, please use method buildTarget instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricTarget getTarget();
  public MetricTarget buildTarget();
  public A withTarget(MetricTarget target);
  public Boolean hasTarget();
  public ResourceMetricSourceFluent.TargetNested<A> withNewTarget();
  public ResourceMetricSourceFluent.TargetNested<A> withNewTargetLike(MetricTarget item);
  public ResourceMetricSourceFluent.TargetNested<A> editTarget();
  public ResourceMetricSourceFluent.TargetNested<A> editOrNewTarget();
  public ResourceMetricSourceFluent.TargetNested<A> editOrNewTargetLike(MetricTarget item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface TargetNested<N> extends Nested<N>,MetricTargetFluent<ResourceMetricSourceFluent.TargetNested<N>>{
    public N and();
    public N endTarget();
    
  }
  
}
